@@ -23,7 +23,7 @@ package neat_test
 import (
 	"testing"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	yamlv3 "gopkg.in/yaml.v3"
